
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU Library General
# Public License along with this library; if not, write to the
# Free Foundation, Inc., 59 Temple Place, Suite 330, Boston,
# MA  02111-1307  USA


###############################################################################
# FUNCTION:           DESCRIPTION:
#  dmvt                Multivariate Student-t Density function
#  pmvt                Multivariate Student-t Probability function
#  qmvt                Multivariate Equicoordinate Student-t Quantile function
#  rmvt                Multivariate Student-t Random Nuber Generator
# REQUIREMENTS:       DESCRIPTION:
#  mvtnorm             Contributed R - Package
###############################################################################


